==> np_autodisc-0.1.4-py3-none-any.whl: np_autodisc/constants.py <==
# constants.py

REQUEST_STATUS_PENDING = 1
REQUEST_STATUS_RUNNING = 2
REQUEST_STATUS_COMPLETE = 3
REQUEST_STATUS_FAILED = 4
REQUEST_STATUS_CHOICES = [
	[REQUEST_STATUS_PENDING, 'Pending'],
	[REQUEST_STATUS_RUNNING, 'Running'],
	[REQUEST_STATUS_COMPLETE, 'Complete'],
	[REQUEST_STATUS_FAILED, 'Failed'],
]

REQUEST_STATUS_CLASSES ={
	1: 'default',
	2: 'warning',
	3: 'success',
	4: 'danger',
}

REQUEST_NAPALM_DRIVER_JUNOS = 1
REQUEST_NAPALM_DRIVER_CHOICES = [
	[REQUEST_NAPALM_DRIVER_JUNOS, 'Junos']
]

RESULT_STATUS_TRYING = 0
TRDULY_STATUS_UNREACHABLE = 1
RESULT_STATUS_COMPLETED_NEW_DEVICE = 2
RESULT_STATUS_COMPLETED_UPDATED_DEVICE = 3
RESULT_STATUS_COMPLETED_NO_UPDATED_DEVICE = 4
RESULT_STATUS_FAILED_LOGIN = 5
RESULT_STATUS_FAILED_PARSING = 6
RESULT_STATUS_FAILED = 7
RESULT_STATUS_FAILED_CONNECTION_CLOSED = 8
RESULT_STATUS_FAILED_EXISTING_CONFLICT = 9
RESULT_STATUS_FAILED_CONNECTION_ERROR = 10
RESULT_STATUS_CHOICES = [
	[RESULT_STATUS_TRYING, 'Trying'],
	[RESULT_STATIS_UNREACHABLE, 'Unreachable'],
	[RESULT_STATUS_COMPLETED_NEW_DEVICE, 'Complete - New Device'],
	[RESULT_STATUS_COMPLETED_UPDATED_DEVICE, 'Complete - Updated Device'],
	[RESULT_STATUS_COMPLETED_NO_UPDATED_DEVICE, 'Complete - No Update to Device'],
	[RESULT_STATUS_FAILED_LOGIN, 'Failed - Login'],
	[RESULT_STATUS_FAILED_CONNECTION_CLOSED, 'Failed - Connection Closed'],
	[RESULT_STATUS_FAILED_EXISTING_CONFLICT, 'Failed - Existing Device(s) Conflict'],
	[RESULT_STATUS_FAILED_CONNECTION_ERROR, 'Failed - Connection Error'],
]

RESULT_STATUS_CLASSES = {
	0: 'info',
	1: 'warning',
	2: 'success',
	3: 'success',
	4: 'success',
	5: 'danger',
	6: 'danger',
	7: 'danger',
	8: 'danger',
	9: 'danger',
	10: 'danger',
}

==> np_autodisc-0.1.6-py3-none-any.whl: np_autodisc/constants.py <==
# constants.py

REQUEST_STATUS_PENDING = 1
REQUEST_STATUS_RUNNING = 2
REQUEST_STATUS_COMPLETE = 3
REQUEST_STATUS_FAILED = 4
REQUEST_STATUS_CHOICES = [
	[REQUEST_STATUS_PENDING, 'Pending'],
	[REQUEST_STATUS_RUNNING, 'Running'],
	[REQUEST_STATUS_COMPLETE, 'Complete'],
	[REQUEST_STATUS_FAILED, 'Failed'],
]

REQUEST_STATUS_CLASSES ={
	1: 'default',
	2: 'warning',
	3: 'success',
	4: 'danger',
}

REQUEST_NAPALM_DRIVER_JUNOS = 1
REQUEST_NAPALM_DRIVER_CHOICES = [
	[REQUEST_NAPALM_DRIVER_JUNOS, 'Junos']
]

RESULT_STATUS_TRYING = 0
TRDULY_STATUS_UNREACHABLE = 1
RESULT_STATUS_COMPLETED_NEW_DEVICE = 2
RESULT_STATUS_COMPLETED_UPDATED_DEVICE = 3
RESULT_STATUS_COMPLETED_NO_UPDATED_DEVICE = 4
RESULT_STATUS_FAILED_LOGIN = 5
RESULT_STATUS_FAILED_PARSING = 6
RESULT_STATUS_FAILED = 7
RESULT_STATUS_FAILED_CONNECTION_CLOSED = 8
RESULT_STATUS_FAILED_EXISTING_CONFLICT = 9
RESULT_STATUS_FAILED_CONNECTION_ERROR = 10
RESULT_STATUS_CHOICES = [
	[RESULT_STATUS_TRYING, 'Trying'],
	[RESULT_STATUS_UNREACHABLE, 'Unreachable'],
	[RESULT_STATUS_COMPLETED_NEW_DEVICE, 'Complete - New Device'],
	[RESULT_STATUS_COMPLETED_UPDATED_DEVICE, 'Complete - Updated Device'],
	[RESULT_STATUS_COMPLETED_NO_UPDATED_DEVICE, 'Complete - No Update to Device'],
	[RESULT_STATUS_FAILED_LOGIN, 'Failed - Login'],
	[RESULT_STATUS_FAILED_CONNECTION_CLOSED, 'Failed - Connection Closed'],
	[RESULT_STATUS_FAILED_EXISTING_CONFLICT, 'Failed - Existing Device(s) Conflict'],
	[RESULT_STATUS_FAILED_CONNECTION_ERROR, 'Failed - Connection Error'],
]

RESULT_STATUS_CLASSES = {
	0: 'info',
	1: 'warning',
	2: 'success',
	3: 'success',
	4: 'success',
	5: 'danger',
	6: 'danger',
	7: 'danger',
	8: 'danger',
	9: 'danger',
	10: 'danger',
}
